@@ -212,29 +212,15 @@ sub getContextProperties($$) {
 	$packageName =~ s/(?<!::)$/::/;
 	my @results;
 	eval {
-	    require DB::IO::Scalar;
 	    my @data;
-	    my $data;
-	    my $ah = DB::IO::Scalar->new(\$data);
+	    open my $ah, '>', \my $data;
 	    defined &main::dumpValue || do 'dumpvar.pl';
 	    if (defined &main::dumpValue) {
 		my $oh = select $ah;
 		# must detect sigpipe failures  - not catching
 		# then will cause the debugger to die.
 		eval {
-		    if ($^V ge v5.8) {
-			# Interface changed with 5.8
-			&main::dumpvar(
-				       $packageName,
-				       -1, # dumpDepth
-				       ()
-				       );
-		    } else {
-			&main::dumpvar(
-				       $packageName,
-				       ()
-				       );
-		    }
+		    &main::dumpvar($packageName, -1);
 		};
 
 		# The die does not need to include the $@, because 
@@ -452,7 +438,7 @@ sub containsWideChar {
     require bytes;
     if (bytes::length($str) > length($str)
 	|| $str =~ /[\x00-\x08\x0b\x0c\x0e-\x1f\x7f-\xff]/
-	|| ($] >= 5.008 && $str =~ /[^\0-\xff]/)) {
+	|| $str =~ /[^\0-\xff]/) {
 	return 1;
     }
     return 0;
